@@ -27,7 +27,7 @@ import optparse
 from . import surface
 
 
-VERSION = '1.0.20'
+VERSION = '1.0.22'
 SURFACES = {
     'SVG': surface.SVGSurface,  # Tell us if you actually use this one!
     'PNG': surface.PNGSurface,
@@ -64,6 +64,9 @@ def main():
     option_parser.add_option(
         '-H', '--height', default=None, type="float",
         help='height of the parent container in pixels')
+    option_parser.add_option(
+        '-u', '--unsafe', action='store_true',
+        help='resolve XML entities (WARNING: vulnerable to XXE attacks)')
     option_parser.add_option(
         "-o", "--output",
         default="", help="output filename")
@@ -76,7 +79,7 @@ def main():
 
     kwargs = {
         'parent_width': options.width, 'parent_height': options.height,
-        'dpi': float(options.dpi)}
+        'dpi': float(options.dpi), 'unsafe': options.unsafe}
 
     if not options.output or options.output == '-':
         # Python 2/3 hack
